#!/usr/bin/env python

##############################################################################
##
## Copyright (C) 2020 Narda Safety Test Solutions GmbH.
## Contact: http://www.narda-sts.de
##
## Redistribution and use in source and binary forms,
## with or without modification, are permitted provided that the following
## conditions are met:
##
## 1.) Redistributions of source code must retain the above copyright notice,
## this list of conditions and the following disclaimer.
##
## 2.) Redistributions in binary form must reproduce the above copyright
## notice, this list of conditions and the following disclaimer in the
## documentation and/or other materials provided with the distribution.
##
## 3.) Neither the name of the copyright holder nor the names of its
## contributors may be used to endorse or promote products derived from this
## software without specific prior written permission.
##
## 4.) EXPORT CONTROL
## The Software, including technical data /cryptographic software,
## may be subject to, German, European Union and U.S. export controls and
## may be subject to import or export controls in other countries.
## The Licensee agrees to strictly comply with all applicable import and
## export regulations. He specifically agrees, that he must not disclose or
## otherwise export or re-export the Licensed Software or any part thereof
## delivered under this end user license agreement (EULA) to any country
## (including a national or resident of such country) without a valid export
## or import license. Please be aware that the Software may contain
## US-Content, therefor the Licensee represent and warrant that he is not a
## citizen of, or otherwise located within, an embargoed nation (including
## without limitation Iran, Syria, Sudan, Cuba, North Korea) and that he is
## not otherwise prohibited under the Export Laws from receiving the Software.
## All rights to Use the Software are granted on condition that such rights
## are forfeited if the Licensee fails to comply with
## the terms of this Agreement.
##
## 5.) SEVERABILITY
## Should any provision of this Agreement be or become invalid, ineffective
## or unenforceable, the remaining provisions of this Agreement shall be
## valid. The parties agree to replace the invalid, ineffective or
## unenforceable provision by a valid, effective and enforceable provision
## which best meets the commercial intention of the parties.
## The same shall apply in case of omissions.
##
## 6.) APPLICABLE LAW AND PLACE OF JURISTICATION
## This Agreement shall be constituted under the law of Germany.
## The United Nations Convention on the International Sale of Goods
## shall not apply to this Agreement. The Place of Jurisdiction for any
## dispute between the Parties shall be Tübingen (Germany).
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## “AS IS” AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
## TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
## PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL Narda Safety Test Solutions GmbH
## BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
## CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
## SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
## INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
## CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
## ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.
##
##############################################################################


import wx
import datetime
from nardascripting.base.usrscriptbase import *
from nardascripting.base.signalsharkdev import *
import nardascripting.base.toolbox as TB


class Example03(UsrScriptBase):
    """User script class"""

    def __init__(self, main_gui, dev=SignalSharkDev()):
        """Initialization. Please leave this line unchanged"""
        super().__init__(main_gui, dev, __file__)

        # Script settings. Please adapt this code to your needs.
        self._tab_name = "Examples"
        self._scr_title = "Example 03 - Dialog Examples"
        self._scr_description = "This script shows some examples of how to setup and use " \
                                "dialogs to show messages and getting input from the user."
        # self._icon_path = self.script_path.joinpath("NardaScriptLauncher_example01.png")
        self._list_prio = 2
        self._nsl_executed_behavior = NSL_Executed_Behaviors.SHOW_NSL

    def _run_script(self, args):
        """
        Script main function
        This method is called when a user clicks on the corresponding script button.
        """

        # Please Note: We are not responsible for the content of any 3rd party website mentioned in this code!

        # --------------------------------------------------------------------------------------
        # wx.MessageBox --> self.MessageBoxModal
        # --------------------------------------------------------------------------------------
        # This is the base method to show a message to the user and to ask for simple decisions
        # https://wxpython.org/Phoenix/docs/html/wx.MessageDialog.html

        # Wrapper function self.MessageBoxModal !!!
        # --------------------------------------------------------------------------------------
        # NardaScriptLauncher provides a wrapper function 'self.MessageBoxModal'
        # which ensures that the MessageBox always remains in the foreground.
        # Please use the wrapper function 'self.MessageBoxModal' instead of 'wx.MessageBox'!

        # You can adapt the behavior and appearance by setting some flags in the method
        # Following list shows some example flags:

        # flag                  |   meaning
        # ================================================
        # wx.OK                 |   show OK button
        # wx.CANCEL             |   show Cancel button
        # wx.YES_NO             |   show Yes, No buttons
        # wx.YES_DEFAULT        |	make Yes button the default
        # wx.NO_DEFAULT         |	make No button the default
        # -------------------------------------------------
        # wx.ICON_EXCLAMATION   |	show an alert icon
        # wx.ICON_ERROR         |   show an error icon
        # wx.ICON_HAND          |	same as wx.ICON_ERROR
        # wx.ICON_INFORMATION   |	show an info icon
        # wx.ICON_QUESTION      |	show a question icon

        # Inform the user about something
        self.MessageBoxModal("Text.", "Caption", wx.OK | wx.ICON_INFORMATION)

        # Ask the user for a decision
        if self.MessageBoxModal("Text", "Caption", wx.YES_NO | wx.ICON_QUESTION) == wx.ID_YES:
            # Do something
            print("User chooses YES")
        else:
            # Do something
            print("User chooses NO")


        # Wrapper function 'self.ShowDlgModalTop(dlg)'!!!
        # --------------------------------------------------------------------------------------
        # NardaScriptLauncher provides a wrapper function 'self.ShowDlgModalTop(dlg)'
        # which ensures that the dialog always remains in the foreground.
        # Please use 'self.frm_dlghelper' as dialog parent and the wrapper function 'self.ShowDlgModalTop(dlg)'
        # instead of 'dlg.ShowModal()'!

        # -------------------------------------------------------------------------------------------------------------
        # wx.TextEntryDialog
        # -------------------------------------------------------------------------------------------------------------
        # This dialog can be used to ask the user to enter some text
        # https://wxpython.org/Phoenix/docs/html/wx.TextEntryDialog.html

        # Ask the user to enter some text
        dlg = wx.TextEntryDialog(self.frm_dlghelper, 'Enter some text', 'Caption')
        dlg.SetValue("Default text")
        if self.ShowDlgModalTop(dlg) == wx.ID_OK:
            print("You entered:" + dlg.GetValue())
        dlg.Destroy()  # Please do not forget to destroy the created dialog if you do not need it anymore

        # -------------------------------------------------------------------------------------------------------------
        # wx.MultiChoiceDialog
        # -------------------------------------------------------------------------------------------------------------
        # This dialog can be used to let the user choose some items from a list
        # https://wxpython.org/Phoenix/docs/html/wx.MultiChoiceDialog.html

        # Ask the user to enter some text
        lst = ["English", "German", "Spanish", "French"]
        def_sel = [1, 2]
        dlg = wx.MultiChoiceDialog(self.frm_dlghelper,
                                   "Pick your language(s)",
                                   "wx.MultiChoiceDialog", lst)
        dlg.SetSelections(def_sel)
        if self.ShowDlgModalTop(dlg) == wx.ID_OK:
            selections = dlg.GetSelections()
            strings = [lst[x] for x in selections]
            print("You chose:" + str(strings))
        dlg.Destroy()  # Please do not forget to destroy the created dialog if you do not need it anymore

        # -------------------------------------------------------------------------------------------------------------
        # nardascripting.base.toolbox.ListMsgBox
        # -------------------------------------------------------------------------------------------------------------
        # This dialog is part of the nardascripting toolbox an can be used to let the user select a value
        # from a combobox.
        # For this example you have to add the following import statement to the import section of your module:
        # from nardascripting.base.toolbox import ListMsgBox

        value_list = ["1", "2", "3", "4", "5"]  # value list as string
        default_value = "1"
        dlg = TB.ListMsgBox(self.frm_dlghelper, "Designator: ",
                            value_list, " Unit", default_value, "Title")
        if self.ShowDlgModalTop(dlg) == wx.ID_OK:
            selected_value = float(dlg.value)
            print(selected_value)
        dlg.Destroy()  # Please do not forget to destroy the created dialog if you do not need it anymore

        # -------------------------------------------------------------------------------------------------------------
        # wx.FileDialog
        # -------------------------------------------------------------------------------------------------------------
        # This dialog can be used to ask the user for a file name
        # https://wxpython.org/Phoenix/docs/html/wx.FileDialog.html

        # Open File Dialog
        dlg = wx.FileDialog(self.frm_dlghelper, "Open", "", "",
                            "Text files (*.txt)|*.txt",
                            wx.FD_OPEN | wx.FD_FILE_MUST_EXIST)

        if self.ShowDlgModalTop(dlg) == wx.ID_OK:
            # Do someting with the filepath
            print(dlg.GetPath())
        dlg.Destroy() # Please do not forget to destroy the created dialog if you do not need it anymore


        # Save File Dialog
        # Sets a default filename, generated out of a given string and the current date time
        # For this example you have to add the following import statement to the import section of your module:
        # import datetime

        initdir = "/"
        default_file_name = datetime.now().strftime("measurement_%Y-%m-%d_%H-%M.csv")
        wildcard = "CSV file (*.csv)|*.csv"
        filename = ""
        dlg = wx.FileDialog(
            self.frm_dlghelper, message="Save measurement data to",
            defaultDir=initdir,
            defaultFile=default_file_name,
            wildcard=wildcard,
            style=wx.FD_SAVE
        )
        if self.ShowDlgModalTop(dlg) == wx.ID_OK:
            filename = dlg.GetPath()
            print(filename)
        dlg.Destroy() # Please do not forget to destroy the created dialog if you do not need it anymore

        # -------------------------------------------------------------------------------------------------------------
        # wx.DirDialog
        # -------------------------------------------------------------------------------------------------------------
        # This dialog can be used to ask the user to choose a folder
        # https://wxpython.org/Phoenix/docs/html/wx.DirDialog.html

        dlg = wx.DirDialog(self.frm_dlghelper, "Choose a folder:",
                           style=wx.DD_DEFAULT_STYLE | wx.DD_DIR_MUST_EXIST | wx.DD_CHANGE_DIR)
        if self.ShowDlgModalTop(dlg) == wx.ID_OK:
            print("Folder: %s" % dlg.GetPath())
        dlg.Destroy() # Please do not forget to destroy the created dialog if you do not need it anymore

        # -------------------------------------------------------------------------------------------------------------
        # Progress Dialog
        # -------------------------------------------------------------------------------------------------------------
        # Please use the UserScript template 'tmpusrscriptmtask.py'.
        # Measurements and calculations that take a longer time (>2s) should be processed in a separate python task!
        # Otherwise the user interface will freeze.
        # The template 'tmpusrscriptmtask.py' supports the multitasking  feature and provides a dialog
        # with a graphical progress bar which can be used to inform the user about the current state
        # of the measurement/calculation.

        # -------------------------------------------------------------------------------------------------------------
        # -------------------------------------------------------------------------------------------------------------
        # There are many more useful wxPython dialogs.
        # Following links show some examples:
        # https://pythonspot.com/wxpython-dialogs/
        # http://www.blog.pythonlibrary.org/2010/06/26/the-dialogs-of-wxpython-part-1-of-2/
        # http://www.blog.pythonlibrary.org/2010/07/10/the-dialogs-of-wxpython-part-2-of-2/
